(function () {
	var Accessor, plugin, registerStore;
	plugin = function (Vue) {
		return Vue.mixin({
			beforeCreate: function () {
				return registerStore(this);
			},
			init: function () {
				return registerStore(this);
			}
		});
	};
	registerStore = function (vm) {
		var base, key, results;
		if (vm.$options.global != null) {
			if ((base = vm.$options).computed == null) {
				base.computed = {};
			}
			if (Array.isArray(vm.$options.global)) {
				return vm.$options.global.forEach(function (property) {
					return vm.$options.computed[property] = new Accessor(property);
				});
			} else {
				results = [];
				for (key in vm.$options.global) {
					if (typeof vm.$options.global[key] === 'function') {
						results.push(vm.$options.computed[key] = new Accessor(vm.$options.global[key]()));
					} else if (typeof vm.$options.global[key] === 'string') {
						results.push(vm.$options.computed[key] = new Accessor(vm.$options.global[key]));
					} else {
						results.push(void 0);
					}
				}
				return results;
			}
		}
	};
	Accessor = function (key) {
		return {
			get: function () {
				return key.split('.').reduce(function (pValue, cValue) {
					return pValue[cValue];
				}, this.$root);
			},
			set: function (value) {
				var global, i, j, path, ref;
				path = key.split('.');
				global = this.$root;
				for (i = j = 0, ref = path.length - 1; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
					if (global.hasOwnProperty(path[i])) {
						global = global[path[i]];
					}
				}
				return global[path[i]] = value;
			}
		};
	};
	if (typeof Vue !== "undefined" && Vue !== null) {
		Vue.use(plugin);
	}
	if (typeof exports === 'object' && typeof module === 'object') {
		return module.exports = plugin;
	} else if (typeof define === 'function' && define.amd) {
		return define(function () {
			return plugin;
		});
	} else if (typeof window !== "undefined" && window !== null) {
		return window.VueGlobal = plugin;
	}
})();